@@ -81,7 +81,7 @@ bool VCalFormat::load( Calendar *calendar, const QString &fileName )
 
   clearException();
 
-  kDebug(5800) << "VCalFormat::load():" << fileName;
+  kDebug() << fileName;
 
   VObject *vcal = 0;
 
@@ -113,7 +113,7 @@ bool VCalFormat::save( Calendar *calendar, const QString &fileName )
   QString tmpStr;
   VObject *vcal, *vo;
 
-  kDebug(5800) << "VCalFormat::save():" << fileName;
+  kDebug() << fileName;
 
   vcal = newVObject( VCCalProp );
 
@@ -124,7 +124,7 @@ bool VCalFormat::save( Calendar *calendar, const QString &fileName )
   // TODO STUFF
   Todo::List todoList = d->mCalendar->rawTodos();
   Todo::List::ConstIterator it;
-  for ( it = todoList.begin(); it != todoList.end(); ++it ) {
+  for ( it = todoList.constBegin(); it != todoList.constEnd(); ++it ) {
     vo = eventToVTodo( *it );
     addVObjectProp( vcal, vo );
   }
@@ -132,7 +132,7 @@ bool VCalFormat::save( Calendar *calendar, const QString &fileName )
   // EVENT STUFF
   Event::List events = d->mCalendar->rawEvents();
   Event::List::ConstIterator it2;
-  for ( it2 = events.begin(); it2 != events.end(); ++it2 ) {
+  for ( it2 = events.constBegin(); it2 != events.constEnd(); ++it2 ) {
     vo = eventToVEvent( *it2 );
     addVObjectProp( vcal, vo );
   }
@@ -142,19 +142,17 @@ bool VCalFormat::save( Calendar *calendar, const QString &fileName )
   cleanStrTbl();
 
   if ( QFile::exists( fileName ) ) {
-    kDebug(5800) << "No error";
     return true;
   } else {
-    kDebug(5800) << "Error";
     return false; // error
   }
 
   return false;
 }
 
-bool VCalFormat::fromString( Calendar *calendar, const QString &text )
+bool VCalFormat::fromString( Calendar *calendar, const QString &string )
 {
-  return fromRawString( calendar, text.toUtf8() );
+  return fromRawString( calendar, string.toUtf8() );
 }
 
 bool VCalFormat::fromRawString( Calendar *calendar, const QByteArray &string )
@@ -184,7 +182,7 @@ bool VCalFormat::fromRawString( Calendar *calendar, const QByteArray &string )
     Event *event = VEventToEvent( curvo );
     calendar->addEvent( event );
   } else {
-    kDebug(5800) << "VCalFormat::fromString(): Unknown object type.";
+    kDebug() << "Unknown object type.";
     deleteVObject( vcal );
     return false;
   }
@@ -265,8 +263,10 @@ VObject *VCalFormat::eventToVTodo( const Todo *anEvent )
 
   // organizer stuff
   // @TODO: How about the common name?
-  tmpStr = "MAILTO:" + anEvent->organizer().email();
-  addPropValue( vtodo, ICOrganizerProp, tmpStr.toLocal8Bit() );
+  if ( !anEvent->organizer().email().isEmpty() ) {
+    tmpStr = "MAILTO:" + anEvent->organizer().email();
+    addPropValue( vtodo, ICOrganizerProp, tmpStr.toLocal8Bit() );
+  }
 
   // attendees
   if ( anEvent->attendeeCount() > 0 ) {
@@ -283,7 +283,7 @@ VObject *VCalFormat::eventToVTodo( const Todo *anEvent )
       } else if ( curAttendee->email().isEmpty() ) {
         tmpStr = "MAILTO: " + curAttendee->name();
       } else if ( curAttendee->name().isEmpty() && curAttendee->email().isEmpty() ) {
-        kDebug(5800) << "warning! this Event has an attendee w/o name or email!";
+        kDebug() << "warning! this Event has an attendee w/o name or email!";
       }
       VObject *aProp = addPropValue( vtodo, VCAttendeeProp, tmpStr.toLocal8Bit() );
       addPropValue( aProp, VCRSVPProp, curAttendee->RSVP() ? "TRUE" : "FALSE" );
@@ -331,7 +331,7 @@ VObject *VCalFormat::eventToVTodo( const Todo *anEvent )
   }
 
   // categories
-  QStringList tmpStrList = anEvent->categories();
+  const QStringList tmpStrList = anEvent->categories();
   tmpStr = "";
   QString catStr;
   QStringList::const_iterator its;
@@ -353,7 +353,6 @@ VObject *VCalFormat::eventToVTodo( const Todo *anEvent )
   }
 
   // alarm stuff
-  kDebug(5800) << "vcalformat::eventToVTodo was called";
   Alarm::List::ConstIterator it;
   for ( it = anEvent->alarms().begin(); it != anEvent->alarms().end(); ++it ) {
     Alarm *alarm = *it;
@@ -424,13 +423,15 @@ VObject *VCalFormat::eventToVEvent( const Event *anEvent )
 
   // attendee and organizer stuff
   // TODO: What to do with the common name?
-  tmpStr = "MAILTO:" + anEvent->organizer().email();
-  addPropValue( vevent, ICOrganizerProp, tmpStr.toLocal8Bit() );
+  if ( !anEvent->organizer().email().isEmpty() ) {
+    tmpStr = "MAILTO:" + anEvent->organizer().email();
+    addPropValue( vevent, ICOrganizerProp, tmpStr.toLocal8Bit() );
+  }
 
   // TODO: Put this functionality into Attendee class
   if ( anEvent->attendeeCount() > 0 ) {
     Attendee::List::ConstIterator it;
-    for ( it = anEvent->attendees().begin(); it != anEvent->attendees().end();
+    for ( it = anEvent->attendees().constBegin(); it != anEvent->attendees().constEnd();
           ++it ) {
       Attendee *curAttendee = *it;
       if ( !curAttendee->email().isEmpty() && !curAttendee->name().isEmpty() ) {
@@ -440,7 +441,7 @@ VObject *VCalFormat::eventToVEvent( const Event *anEvent )
       } else if ( curAttendee->email().isEmpty() ) {
         tmpStr = "MAILTO: " + curAttendee->name();
       } else if ( curAttendee->name().isEmpty() && curAttendee->email().isEmpty() ) {
-        kDebug(5800) << "warning! this Event has an attendee w/o name or email!";
+        kDebug() << "warning! this Event has an attendee w/o name or email!";
       }
       VObject *aProp = addPropValue( vevent, VCAttendeeProp, tmpStr.toLocal8Bit() );
       addPropValue( aProp, VCRSVPProp, curAttendee->RSVP() ? "TRUE" : "FALSE" );
@@ -459,7 +460,7 @@ VObject *VCalFormat::eventToVEvent( const Event *anEvent )
       break;
     case Recurrence::rWeekly:
       tmpStr.sprintf( "W%i ", recur->frequency() );
-      for ( int i = 0; i < 7; i++ ) {
+      for ( int i = 0; i < 7; ++i ) {
         QBitArray days ( recur->days() );
         if ( days.testBit(i) ) {
           tmpStr += dayFromNum( i );
@@ -471,8 +472,8 @@ VObject *VCalFormat::eventToVEvent( const Event *anEvent )
       tmpStr.sprintf( "MP%i ", recur->frequency() );
       // write out all rMonthPos's
       QList<RecurrenceRule::WDayPos> tmpPositions = recur->monthPositions();
-      for ( QList<RecurrenceRule::WDayPos>::ConstIterator posit = tmpPositions.begin();
-            posit != tmpPositions.end(); ++posit ) {
+      for ( QList<RecurrenceRule::WDayPos>::ConstIterator posit = tmpPositions.constBegin();
+            posit != tmpPositions.constEnd(); ++posit ) {
         int pos = (*posit).pos();
         tmpStr2.sprintf( "%i", ( pos > 0 ) ? pos : (-pos) );
         if ( pos < 0 ) {
@@ -489,9 +490,9 @@ VObject *VCalFormat::eventToVEvent( const Event *anEvent )
     {
       tmpStr.sprintf( "MD%i ", recur->frequency() );
       // write out all rMonthDays;
-      QList<int> tmpDays = recur->monthDays();
-      for ( QList<int>::Iterator tmpDay = tmpDays.begin();
-            tmpDay != tmpDays.end(); ++tmpDay ) {
+      const QList<int> tmpDays = recur->monthDays();
+      for ( QList<int>::ConstIterator tmpDay = tmpDays.constBegin();
+            tmpDay != tmpDays.constEnd(); ++tmpDay ) {
         tmpStr2.sprintf( "%i ", *tmpDay );
         tmpStr += tmpStr2;
       }
@@ -502,9 +503,9 @@ VObject *VCalFormat::eventToVEvent( const Event *anEvent )
       tmpStr.sprintf( "YM%i ", recur->frequency() );
       // write out all the months;'
       // TODO: Any way to write out the day within the month???
-      QList<int> months = recur->yearMonths();
-      for ( QList<int>::Iterator mit = months.begin();
-            mit != months.end(); ++mit ) {
+      const QList<int> months = recur->yearMonths();
+      for ( QList<int>::ConstIterator mit = months.constBegin();
+            mit != months.constEnd(); ++mit ) {
         tmpStr2.sprintf( "%i ", *mit );
         tmpStr += tmpStr2;
       }
@@ -514,8 +515,8 @@ VObject *VCalFormat::eventToVEvent( const Event *anEvent )
     {
       tmpStr.sprintf( "YD%i ", recur->frequency() );
       // write out all the rYearNums;
-      QList<int> tmpDays = recur->yearDays();
-      for ( QList<int>::Iterator tmpDay = tmpDays.begin();
+      const QList<int> tmpDays = recur->yearDays();
+      for ( QList<int>::ConstIterator tmpDay = tmpDays.begin();
             tmpDay != tmpDays.end(); ++tmpDay ) {
         tmpStr2.sprintf( "%i ", *tmpDay );
         tmpStr += tmpStr2;
@@ -524,7 +525,7 @@ VObject *VCalFormat::eventToVEvent( const Event *anEvent )
     }
     default:
       // TODO: Write rYearlyPos and arbitrary rules!
-      kDebug(5800) << "ERROR, it should never get here in eventToVEvent!";
+      kDebug() << "ERROR, it should never get here in eventToVEvent!";
       validRecur = false;
       break;
     } // switch
@@ -550,13 +551,13 @@ VObject *VCalFormat::eventToVEvent( const Event *anEvent )
   DateList::ConstIterator it;
   QString tmpStr2;
 
-  for ( it = dateList.begin(); it != dateList.end(); ++it ) {
+  for ( it = dateList.constBegin(); it != dateList.constEnd(); ++it ) {
     tmpStr = qDateToISO(*it) + ';';
     tmpStr2 += tmpStr;
   }
   if ( !tmpStr2.isEmpty() ) {
     tmpStr2.truncate( tmpStr2.length() - 1 );
-    addPropValue( vevent, VCExDateProp, tmpStr2.toLocal8Bit() );
+    addPropValue( vevent, VCExpDateProp, tmpStr2.toLocal8Bit() );
   }
 
   // description
@@ -603,7 +604,7 @@ VObject *VCalFormat::eventToVEvent( const Event *anEvent )
   QStringList tmpStrList = anEvent->categories();
   tmpStr = "";
   QString catStr;
-  for ( QStringList::Iterator it = tmpStrList.begin(); it != tmpStrList.end();
+  for ( QStringList::const_iterator it = tmpStrList.constBegin(); it != tmpStrList.constEnd();
         ++it ) {
     catStr = *it;
     if ( catStr[0] == ' ' ) {
@@ -625,7 +626,7 @@ VObject *VCalFormat::eventToVEvent( const Event *anEvent )
   // TODO: handle binary attachments!
   Attachment::List attachments = anEvent->attachments();
   Attachment::List::ConstIterator atIt;
-  for ( atIt = attachments.begin(); atIt != attachments.end(); ++atIt ) {
+  for ( atIt = attachments.constBegin(); atIt != attachments.constEnd(); ++atIt ) {
     addPropValue( vevent, VCAttachProp, (*atIt)->uri().toLocal8Bit() );
   }
 
@@ -638,7 +639,7 @@ VObject *VCalFormat::eventToVEvent( const Event *anEvent )
 
   // alarm stuff
   Alarm::List::ConstIterator it2;
-  for ( it2 = anEvent->alarms().begin(); it2 != anEvent->alarms().end(); ++it2 ) {
+  for ( it2 = anEvent->alarms().constBegin(); it2 != anEvent->alarms().constEnd(); ++it2 ) {
     Alarm *alarm = *it2;
     if ( alarm->enabled() ) {
       VObject *a = addProp( vevent, VCDAlarmProp );
@@ -791,7 +792,7 @@ Todo *VCalFormat::VTodoToEvent( VObject *vtodo )
   // was: status
   if ( ( vo = isAPropertyOf( vtodo, VCStatusProp ) ) != 0 ) {
     s = fakeCString( vObjectUStringZValue( vo ) );
-    if ( strcmp( s, "COMPLETED" ) == 0 ) {
+    if ( s && strcmp( s, "COMPLETED" ) == 0 ) {
       anEvent->setCompleted( true );
     } else {
       anEvent->setCompleted( false );
@@ -809,8 +810,11 @@ Todo *VCalFormat::VTodoToEvent( VObject *vtodo )
 
   // priority
   if ( ( vo = isAPropertyOf( vtodo, VCPriorityProp ) ) ) {
-    anEvent->setPriority( atoi( s = fakeCString( vObjectUStringZValue( vo ) ) ) );
-    deleteStr( s );
+    s = fakeCString( vObjectUStringZValue( vo ) );
+    if ( s ) {
+      anEvent->setPriority( atoi( s ) );
+      deleteStr( s );
+    }
   }
 
   // due date
@@ -914,11 +918,13 @@ Event *VCalFormat::VEventToEvent( VObject *vevent )
 
   // revision
   // again NSCAL doesn't give us much to work with, so we improvise...
+  anEvent->setRevision( 0 );
   if ( ( vo = isAPropertyOf( vevent, VCSequenceProp ) ) != 0 ) {
-    anEvent->setRevision( atoi( s = fakeCString( vObjectUStringZValue( vo ) ) ) );
-    deleteStr( s );
-  } else {
-    anEvent->setRevision( 0 );
+    s = fakeCString( vObjectUStringZValue( vo ) );
+    if ( s ) {
+      anEvent->setRevision( atoi( s ) );
+      deleteStr( s );
+    }
   }
 
   // last modification date
@@ -1025,7 +1031,6 @@ Event *VCalFormat::VEventToEvent( VObject *vevent )
     deleteStr( s );
     tmpStr.simplified();
     tmpStr = tmpStr.toUpper();
-// kDebug(5800) <<" We have a recurrence rule:" << tmpStr;
 
     // first, read the type of the recurrence
     int typelen = 1;
@@ -1048,7 +1053,6 @@ Event *VCalFormat::VEventToEvent( VObject *vevent )
     }
 
     if ( type != Recurrence::rNone ) {
-// kDebug(5800) << " It's a supported type";
 
       // Immediately after the type is the frequency
       int index = tmpStr.indexOf( ' ' );
@@ -1074,7 +1078,9 @@ Event *VCalFormat::VEventToEvent( VObject *vevent )
           while ( index < last ) {
             dayStr = tmpStr.mid( index, 3 );
             int dayNum = numFromDay( dayStr );
-            qba.setBit( dayNum );
+            if ( dayNum >= 0 ) {
+              qba.setBit( dayNum );
+            }
             index += 3; // advance to next day, or possibly "#"
           }
         }
@@ -1197,16 +1203,16 @@ Event *VCalFormat::VEventToEvent( VObject *vevent )
 // anEvent->recurrence()->dump();
 
     } else {
-      kDebug(5800) << "we don't understand this type of recurrence!";
+      kDebug() << "we don't understand this type of recurrence!";
     } // if known recurrence type
   } // repeats
 
   // recurrence exceptions
-  if ( ( vo = isAPropertyOf( vevent, VCExDateProp ) ) != 0 ) {
+  if ( ( vo = isAPropertyOf( vevent, VCExpDateProp ) ) != 0 ) {
     s = fakeCString( vObjectUStringZValue( vo ) );
-    QStringList exDates = QString::fromLocal8Bit( s ).split( "," );
+    QStringList exDates = QString::fromLocal8Bit( s ).split( ',' );
     QStringList::ConstIterator it;
-    for ( it = exDates.begin(); it != exDates.end(); ++it ) {
+    for ( it = exDates.constBegin(); it != exDates.constEnd(); ++it ) {
       anEvent->recurrence()->addExDate( ISOToQDate(*it) );
     }
     deleteStr( s );
@@ -1263,9 +1269,9 @@ Event *VCalFormat::VEventToEvent( VObject *vevent )
   Incidence::Secrecy secrecy = Incidence::SecrecyPublic;
   if ( ( vo = isAPropertyOf( vevent, VCClassProp ) ) != 0 ) {
     s = fakeCString( vObjectUStringZValue( vo ) );
-    if ( strcmp( s, "PRIVATE" ) == 0 ) {
+    if ( s && strcmp( s, "PRIVATE" ) == 0 ) {
       secrecy = Incidence::SecrecyPrivate;
-    } else if ( strcmp( s, "CONFIDENTIAL" ) == 0 ) {
+    } else if ( s && strcmp( s, "CONFIDENTIAL" ) == 0 ) {
       secrecy = Incidence::SecrecyConfidential;
     }
     deleteStr( s );
@@ -1327,15 +1333,21 @@ Event *VCalFormat::VEventToEvent( VObject *vevent )
 
   // priority
   if ( ( vo = isAPropertyOf( vevent, VCPriorityProp ) ) ) {
-    anEvent->setPriority( atoi( s = fakeCString( vObjectUStringZValue( vo ) ) ) );
-    deleteStr( s );
+    s = fakeCString( vObjectUStringZValue( vo ) );
+    if ( s ) {
+      anEvent->setPriority( atoi( s ) );
+      deleteStr( s );
+    }
   }
 
   // transparency
   if ( ( vo = isAPropertyOf( vevent, VCTranspProp ) ) != 0 ) {
-    int i = atoi( s = fakeCString( vObjectUStringZValue( vo ) ) );
-    anEvent->setTransparency( i == 1 ? Event::Transparent : Event::Opaque );
-    deleteStr( s );
+    s = fakeCString( vObjectUStringZValue( vo ) );
+    if ( s ) {
+      int i = atoi( s );
+      anEvent->setTransparency( i == 1 ? Event::Transparent : Event::Opaque );
+      deleteStr( s );
+    }
   }
 
   // related event
@@ -1366,7 +1378,9 @@ QString VCalFormat::qDateToISO( const QDate &qd )
 {
   QString tmpStr;
 
-  Q_ASSERT( qd.isValid() );
+  if ( !qd.isValid() ) {
+    return QString();
+  }
 
   tmpStr.sprintf( "%.2d%.2d%.2d", qd.year(), qd.month(), qd.day() );
   return tmpStr;
@@ -1377,7 +1391,10 @@ QString VCalFormat::kDateTimeToISO( const KDateTime &dt, bool zulu )
 {
   QString tmpStr;
 
-  Q_ASSERT( dt.isValid() );
+  if ( !dt.isValid() ) {
+    return QString();
+  }
+
   QDateTime tmpDT;
   if ( zulu ) {
     tmpDT = dt.toUtc().dateTime();
@@ -1411,13 +1428,15 @@ KDateTime VCalFormat::ISOToKDateTime( const QString &dtStr )
   tmpDate.setYMD( year, month, day );
   tmpTime.setHMS( hour, minute, second );
 
-  Q_ASSERT( tmpDate.isValid() );
-  Q_ASSERT( tmpTime.isValid() );
-  // correct for GMT if string is in Zulu format
-  if ( dtStr.at( dtStr.length() - 1 ) == 'Z' ) {
-    return KDateTime( tmpDate, tmpTime, KDateTime::UTC );
+  if ( tmpDate.isValid() && tmpTime.isValid() ) {
+    // correct for GMT if string is in Zulu format
+    if ( dtStr.at( dtStr.length() - 1 ) == 'Z' ) {
+      return KDateTime( tmpDate, tmpTime, KDateTime::UTC );
+    } else {
+      return KDateTime( tmpDate, tmpTime, d->mCalendar->timeSpec() );
+    }
   } else {
-    return KDateTime( tmpDate, tmpTime, d->mCalendar->timeSpec() );
+    return KDateTime();
   }
 }
 
@@ -1447,17 +1466,17 @@ void VCalFormat::populate( VObject *vcal )
   if ( ( curVO = isAPropertyOf( vcal, ICMethodProp ) ) != 0 ) {
     char *methodType = 0;
     methodType = fakeCString( vObjectUStringZValue( curVO ) );
-    kDebug(5800) << "This calendar is an iTIP transaction of type '"
-                 << methodType << "'";
+    kDebug() << "This calendar is an iTIP transaction of type '"
+             << methodType << "'";
     deleteStr( methodType );
   }
 
   // warn the user that we might have trouble reading non-known calendar.
   if ( ( curVO = isAPropertyOf( vcal, VCProdIdProp ) ) != 0 ) {
     char *s = fakeCString( vObjectUStringZValue( curVO ) );
-    if ( strcmp( productId().toLocal8Bit(), s ) != 0 ) {
-      kDebug(5800) << "This vCalendar file was not created by KOrganizer or"
-                   << "any other product we support. Loading anyway...";
+    if ( !s || strcmp( productId().toLocal8Bit(), s ) != 0 ) {
+      kDebug() << "This vCalendar file was not created by KOrganizer or"
+               << "any other product we support. Loading anyway...";
     }
     setLoadedProductId( s );
     deleteStr( s );
@@ -1466,9 +1485,9 @@ void VCalFormat::populate( VObject *vcal )
   // warn the user we might have trouble reading this unknown version.
   if ( ( curVO = isAPropertyOf( vcal, VCVersionProp ) ) != 0 ) {
     char *s = fakeCString( vObjectUStringZValue( curVO ) );
-    if ( strcmp( _VCAL_VERSION, s ) != 0 ) {
-      kDebug(5800) << "This vCalendar file has version" << s
-                   << "We only support" << _VCAL_VERSION;
+    if ( !s || strcmp( _VCAL_VERSION, s ) != 0 ) {
+      kDebug() << "This vCalendar file has version" << s
+               << "We only support" << _VCAL_VERSION;
     }
     deleteStr( s );
   }
@@ -1501,12 +1520,14 @@ void VCalFormat::populate( VObject *vcal )
         char *s;
         s = fakeCString( vObjectUStringZValue( curVOProp ) );
         // check to see if event was deleted by the kpilot conduit
-        if ( atoi( s ) == SYNCDEL ) {
+        if ( s ) {
+          if ( atoi( s ) == SYNCDEL ) {
+            deleteStr( s );
+            kDebug() << "skipping pilot-deleted event";
+            goto SKIP;
+          }
           deleteStr( s );
-          kDebug(5800) << "skipping pilot-deleted event";
-          goto SKIP;
         }
-        deleteStr( s );
       }
 
       // this code checks to see if we are trying to read in an event
@@ -1524,7 +1545,7 @@ void VCalFormat::populate( VObject *vcal )
 
       if ( ( !( curVOProp = isAPropertyOf( curVO, VCDTstartProp ) ) ) &&
            ( !( curVOProp = isAPropertyOf( curVO, VCDTendProp ) ) ) ) {
-        kDebug(5800) << "found a VEvent with no DTSTART and no DTEND! Skipping...";
+        kDebug() << "found a VEvent with no DTSTART and no DTEND! Skipping...";
         goto SKIP;
       }
 
@@ -1532,9 +1553,7 @@ void VCalFormat::populate( VObject *vcal )
       // we now use addEvent instead of insertEvent so that the
       // signal/slot get connected.
       if ( anEvent ) {
-        if ( !anEvent->dtStart().isValid() || !anEvent->dtEnd().isValid() ) {
-          kDebug(5800) << "VCalFormat::populate(): Event has invalid dates.";
-        } else {
+        if ( anEvent->dtStart().isValid() && anEvent->dtEnd().isValid() ) {
           d->mCalendar->addEvent( anEvent );
         }
       } else {
@@ -1543,6 +1562,13 @@ void VCalFormat::populate( VObject *vcal )
       }
     } else if ( strcmp( vObjectName( curVO ), VCTodoProp ) == 0 ) {
       Todo *aTodo = VTodoToEvent( curVO );
+
+      Todo *old = d->mCalendar->todo( aTodo->uid() );
+      if ( old ) {
+        d->mCalendar->deleteTodo( old );
+        d->mTodosRelate.removeAll( old );
+      }
+
       d->mCalendar->addTodo( aTodo );
     } else if ( ( strcmp( vObjectName( curVO ), VCVersionProp ) == 0 ) ||
                 ( strcmp( vObjectName( curVO ), VCProdIdProp ) == 0 ) ||
@@ -1551,7 +1577,7 @@ void VCalFormat::populate( VObject *vcal )
       // we have either already processed them or are ignoring them.
       ;
     } else {
-      kDebug(5800) << "Ignoring unknown vObject \"" << vObjectName(curVO) << "\"";
+      kDebug() << "Ignoring unknown vObject \"" << vObjectName(curVO) << "\"";
     }
   SKIP:
     ;
@@ -1559,11 +1585,11 @@ void VCalFormat::populate( VObject *vcal )
 
   // Post-Process list of events with relations, put Event objects in relation
   Event::List::ConstIterator eIt;
-  for ( eIt = d->mEventsRelate.begin(); eIt != d->mEventsRelate.end(); ++eIt ) {
+  for ( eIt = d->mEventsRelate.constBegin(); eIt != d->mEventsRelate.constEnd(); ++eIt ) {
     (*eIt)->setRelatedTo( d->mCalendar->incidence( (*eIt)->relatedToUid() ) );
   }
   Todo::List::ConstIterator tIt;
-  for ( tIt = d->mTodosRelate.begin(); tIt != d->mTodosRelate.end(); ++tIt ) {
+  for ( tIt = d->mTodosRelate.constBegin(); tIt != d->mTodosRelate.constEnd(); ++tIt ) {
     (*tIt)->setRelatedTo( d->mCalendar->incidence( (*tIt)->relatedToUid() ) );
    }
 }
@@ -1627,7 +1653,7 @@ Attendee::PartStat VCalFormat::readStatus( const char *s ) const
   } else if ( statStr == "DELEGATED" ) {
     status = Attendee::Delegated;
   } else {
-    kDebug(5800) << "error setting attendee mStatus, unknown mStatus!";
+    kDebug() << "error setting attendee mStatus, unknown mStatus!";
     status = Attendee::NeedsAction;
   }
 
