@@ -26,6 +26,7 @@
  *
  */
 #include "pop3.h"
+#include "common.h"
 
 #include <sys/types.h>
 #include <sys/socket.h>
@@ -38,11 +39,9 @@
 #include <errno.h>
 #include <stdio.h>
 
-#ifdef HAVE_LIBSASL2
 extern "C" {
 #include <sasl/sasl.h>
 }
-#endif
 
 #include <QtCore/QBool>
 #include <QCoreApplication>
@@ -67,7 +66,6 @@ extern "C" {
 
 using namespace KIO;
 
-#ifdef HAVE_LIBSASL2
 static sasl_callback_t callbacks[] = {
     { SASL_CB_ECHOPROMPT, NULL, NULL },
     { SASL_CB_NOECHOPROMPT, NULL, NULL },
@@ -78,7 +76,6 @@ static sasl_callback_t callbacks[] = {
     { SASL_CB_CANON_USER, NULL, NULL },
     { SASL_CB_LIST_END, NULL, NULL }
 };
-#endif
 
 int kdemain(int argc, char **argv)
 {
@@ -88,18 +85,14 @@ int kdemain(int argc, char **argv)
     return -1;
   }
 
-#ifdef HAVE_LIBSASL2
-  if ( sasl_client_init( NULL ) != SASL_OK ) {
-    fprintf(stderr, "SASL library initialization failed!\n");
-    return -1;
-  }
-#endif
-
   QCoreApplication app( argc, argv ); // needed for QSocketNotifier
   KComponentData componentData("kio_pop3");
-  POP3Protocol *slave;
+
+  if (!initSASL())
+    return -1;
 
   // Are we looking to use SSL?
+  POP3Protocol *slave;
   if (strcasecmp(argv[1], "pop3s") == 0) {
     slave = new POP3Protocol(argv[2], argv[3], true);
   } else {
@@ -109,9 +102,7 @@ int kdemain(int argc, char **argv)
   slave->dispatchLoop();
   delete slave;
 
-#ifdef HAVE_LIBSASL2
   sasl_done();
-#endif
 
   return 0;
 }
@@ -394,7 +385,6 @@ int POP3Protocol::loginAPOP( char *challenge, KIO::AuthInfo &ai )
 
 bool POP3Protocol::saslInteract( void *in, AuthInfo &ai )
 {
-#ifdef HAVE_LIBSASL2
   kDebug(7105);
   sasl_interact_t *interact = ( sasl_interact_t * ) in;
 
@@ -438,9 +428,6 @@ bool POP3Protocol::saslInteract( void *in, AuthInfo &ai )
     interact++;
   }
   return true;
-#else
-  return false;
-#endif
 }
 
 #define SASLERROR  closeConnection(); \
@@ -449,7 +436,6 @@ error(ERR_COULD_NOT_AUTHENTICATE, i18n("An error occurred during authentication:
 
 int POP3Protocol::loginSASL( KIO::AuthInfo &ai )
 {
-#ifdef HAVE_LIBSASL2
   char buf[512];
   QString sasl_buffer = QString::fromLatin1("AUTH");
 
@@ -484,7 +470,7 @@ int POP3Protocol::loginSASL( KIO::AuthInfo &ai )
         myReadLine(buf, sizeof(buf) - 1);
 
         // HACK: This assumes fread stops at the first \n and not \r
-        if (strcmp(buf, ".\r\n") == 0) {
+        if ( (buf[0] == 0) || (strcmp(buf, ".\r\n") == 0) ) {
           break;              // End of data
         }
         // sanders, changed -2 to -1 below
@@ -578,14 +564,6 @@ int POP3Protocol::loginSASL( KIO::AuthInfo &ai )
     return -1;
   }
   return 1;
-#else
-  if (metaData("auth") == "SASL") {
-    closeConnection();
-    error(ERR_COULD_NOT_LOGIN, i18n("SASL authentication is not compiled into kio_pop3."));
-    return -1;
-  }
-  return 1; //if SASL not explicitly required, try another method (USER/PASS)
-#endif
 }
 
 bool POP3Protocol::loginPASS( KIO::AuthInfo &ai )
@@ -780,35 +758,6 @@ size_t POP3Protocol::realGetSize(unsigned int msg_num)
   return ret;
 }
 
-void POP3Protocol::special(const QByteArray & aData)
-{
-  QString result;
-  char buf[MAX_PACKET_LEN];
-  QDataStream stream(aData);
-  int tmp;
-  stream >> tmp;
-
-  if (tmp != 'c')
-    return;
-
-  for (int i = 0; i < 2; i++) {
-    QByteArray cmd = (i) ? "AUTH" : "CAPA";
-    if ( command(cmd) != Ok )
-      continue;
-    while (true) {
-      myReadLine(buf, MAX_PACKET_LEN - 1);
-      if (qstrcmp(buf, ".\r\n") == 0)
-        break;
-      result += ' ' + QString(buf).left(strlen(buf) - 2).replace(" ", "-");
-    }
-  }
-  if (supports_apop)
-    result += " APOP";
-  result = result.mid(1);
-  infoMessage(result);
-  finished();
-}
-
 void POP3Protocol::get(const KUrl & url)
 {
 // List of supported commands
@@ -882,7 +831,7 @@ void POP3Protocol::get(const KUrl & url)
         myReadLine(buf, sizeof(buf) - 1);
 
         // HACK: This assumes fread stops at the first \n and not \r
-        if (strcmp(buf, ".\r\n") == 0) {
+        if ( (buf[0] == 0) || (strcmp(buf, ".\r\n") == 0) ) {
           break;                // End of data
         }
         // sanders, changed -2 to -1 below
@@ -897,9 +846,9 @@ void POP3Protocol::get(const KUrl & url)
     data(QByteArray());
     finished();
   } else if (cmd == "remove") {
-    QStringList waitingCommands = path.split(',');
+    const QStringList waitingCommands = path.split(',');
     int activeCommands = 0;
-    QStringList::Iterator it = waitingCommands.begin();
+    QStringList::ConstIterator it = waitingCommands.begin();
     while (it != waitingCommands.end() || activeCommands > 0) {
       while (activeCommands < maxCommands && it != waitingCommands.end()) {
         sendCommand(("DELE " + *it).toLatin1());
@@ -912,7 +861,7 @@ void POP3Protocol::get(const KUrl & url)
     finished();
     m_cmd = CMD_NONE;
   } else if (cmd == "download" || cmd == "headers") {
-    QStringList waitingCommands = path.split(',', QString::SkipEmptyParts);
+    const QStringList waitingCommands = path.split(',', QString::SkipEmptyParts);
     bool noProgress = (metaData("progress") == "off"
                        || waitingCommands.count() > 1);
     int p_size = 0;
@@ -947,7 +896,7 @@ void POP3Protocol::get(const KUrl & url)
     }
 
     int activeCommands = 0;
-    QStringList::Iterator it = waitingCommands.begin();
+    QStringList::ConstIterator it = waitingCommands.begin();
     while (it != waitingCommands.end() || activeCommands > 0) {
       while (activeCommands < maxCommands && it != waitingCommands.end()) {
         sendCommand(((cmd ==
@@ -1098,13 +1047,13 @@ void POP3Protocol::listDir(const KUrl &)
   // Check how many messages we have. STAT is by law required to
   // at least return +OK num_messages total_size
   if ( command("STAT", q_buf.data(), MAX_RESPONSE_LEN) != Ok ) {
-    error(ERR_INTERNAL, "??");
+    error(ERR_INTERNAL, i18n("The POP3 command 'STAT' failed"));
     return;
   }
   kDebug(7105) << "The stat buf is :" << q_buf << ":";
   if (q_buf.indexOf(" ") == -1) {
     error(ERR_INTERNAL,
-          "Invalid POP3 response, we should have at least one space!");
+          i18n("Invalid POP3 response, should have at least one space."));
     closeConnection();
     return;
   }
@@ -1112,7 +1061,7 @@ void POP3Protocol::listDir(const KUrl &)
 
   num_messages = q_buf.toUInt(&isINT);
   if (!isINT) {
-    error(ERR_INTERNAL, "Invalid POP3 STAT response!");
+    error(ERR_INTERNAL, i18n("Invalid POP3 STAT response."));
     closeConnection();
     return;
   }
@@ -1169,7 +1118,7 @@ void POP3Protocol::stat(const KUrl & url)
 
 void POP3Protocol::del(const KUrl & url, bool /*isfile */ )
 {
-  QString invalidURI = QString();
+  QString invalidURI;
   bool isInt;
 
   if (!pop3_open()) {
